@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2005 IBM Corporation and others.
+ * Copyright (c) 2000, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Erling Ellingsen -  patch for bug 125570
  *******************************************************************************/
 package org.eclipse.jdt.internal.compiler.lookup;
 
@@ -60,6 +61,7 @@ void buildFieldsAndMethods() {
 }
 void buildTypeBindings(AccessRestriction accessRestriction) {
 	topLevelTypes = new SourceTypeBinding[0]; // want it initialized if the package cannot be resolved
+	boolean firstIsSynthetic = false;
 	if (referenceContext.compilationResult.compilationUnit != null) {
 		char[][] expectedPackageName = referenceContext.compilationResult.compilationUnit.getPackageName();
 		if (expectedPackageName != null 
@@ -83,6 +85,16 @@ void buildTypeBindings(AccessRestriction accessRestriction) {
 		if ((fPackage = environment.createPackage(currentPackageName)) == null) {
 			problemReporter().packageCollidesWithType(referenceContext);
 			return;
+		} else if (referenceContext.isPackageInfo() && referenceContext.currentPackage.annotations != null) {
+			// resolve package annotations now if this is "package-info.java".				
+			if (referenceContext.types == null || referenceContext.types.length == 0) {
+				referenceContext.types = new TypeDeclaration[1];
+				TypeDeclaration declaration = new TypeDeclaration(referenceContext.compilationResult);
+				referenceContext.types[0] = declaration;
+				declaration.name = TypeConstants.PACKAGE_INFO_NAME;
+				declaration.modifiers = ClassFileConstants.AccDefault | ClassFileConstants.AccInterface;
+				firstIsSynthetic = true;
+			}
 		}
 		recordQualifiedReference(currentPackageName); // always dependent on your own package
 	}
@@ -108,7 +120,7 @@ void buildTypeBindings(AccessRestriction accessRestriction) {
 			continue nextType;
 		}
 
-		if ((typeDecl.modifiers & AccPublic) != 0) {
+		if ((typeDecl.modifiers & ClassFileConstants.AccPublic) != 0) {
 			char[] mainTypeName;
 			if ((mainTypeName = referenceContext.getMainTypeName()) != null // mainTypeName == null means that implementor of ICompilationUnit decided to return null
 					&& !CharOperation.equals(mainTypeName, typeDecl.name)) {
@@ -119,9 +131,10 @@ void buildTypeBindings(AccessRestriction accessRestriction) {
 
 		ClassScope child = new ClassScope(this, typeDecl);
 		SourceTypeBinding type = child.buildType(null, fPackage, accessRestriction);
-		if(type != null) {
+		if (firstIsSynthetic && i == 0)
+			type.modifiers |= ClassFileConstants.AccSynthetic;
+		if (type != null)
 			topLevelTypes[count++] = type;
-		}
 	}
 
 	// shrink topLevelTypes... only happens if an error was reported
@@ -179,6 +192,19 @@ void checkAndSetImports() {
 		System.arraycopy(resolvedImports, 0, resolvedImports = new ImportBinding[index], 0, index);
 	imports = resolvedImports;
 }
+
+/**
+ * Perform deferred check specific to parameterized types: bound checks, supertype collisions
+ */
+void checkParameterizedTypes() {
+	if (compilerOptions().sourceLevel < ClassFileConstants.JDK1_5) return;
+
+	for (int i = 0, length = topLevelTypes.length; i < length; i++) {
+		ClassScope scope = topLevelTypes[i].scope;
+		scope.checkParameterizedTypeBounds();
+		scope.checkParameterizedSuperTypeCollisions();
+	}
+}
 /*
  * INTERNAL USE-ONLY
  * Innerclasses get their name computed as they are generated, since some may not
@@ -217,16 +243,24 @@ public char[] computeConstantPoolName(LocalTypeBinding localType) {
 					localType.sourceName);
 			}
 		} else if (localType.isAnonymousType()){
+			if (isCompliant15) {
+				// from 1.5 on, use immediately enclosing type name
+				candidateName = CharOperation.concat(
+					localType.enclosingType.constantPoolName(),
+					String.valueOf(index+1).toCharArray(),
+					'$');
+			} else {
 				candidateName = CharOperation.concat(
 					outerMostEnclosingType.constantPoolName(),
 					String.valueOf(index+1).toCharArray(),
 					'$');
+			}
 		} else {
 			// local type
 			if (isCompliant15) {
 				candidateName = CharOperation.concat(
 					CharOperation.concat(
-						outerMostEnclosingType.constantPoolName(),
+						localType.enclosingType().constantPoolName(),
 						String.valueOf(index+1).toCharArray(),
 						'$'),
 					localType.sourceName);
@@ -237,7 +271,7 @@ public char[] computeConstantPoolName(LocalTypeBinding localType) {
 					String.valueOf(index+1).toCharArray(),
 					'$',
 					localType.sourceName);
-			}				
+			}
 		}						
 		if (constantPoolNameUsage.get(candidateName) != null) {
 			index ++;
@@ -416,27 +450,28 @@ private Binding findImport(char[][] compoundName, int length) {
 	ReferenceBinding type;
 	if (binding == null) {
 		if (environment.defaultPackage == null || compilerOptions().complianceLevel >= ClassFileConstants.JDK1_4)
-			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), NotFound);
+			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), null, ProblemReasons.NotFound);
 		type = findType(compoundName[0], environment.defaultPackage, environment.defaultPackage);
 		if (type == null || !type.isValidBinding())
-			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), NotFound);
+			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), null, ProblemReasons.NotFound);
 		i = 1; // reset to look for member types inside the default package type
 	} else {
 		type = (ReferenceBinding) binding;
 	}
 
 	while (i < length) {
+		type = (ReferenceBinding)environment.convertToRawType(type); // type imports are necessarily raw for all except last
 		if (!type.canBeSeenBy(fPackage))
-			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), type, NotVisible);
+			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), type, ProblemReasons.NotVisible);
 
 		char[] name = compoundName[i++];
 		// does not look for inherited member types on purpose, only immediate members
 		type = type.getMemberType(name);
 		if (type == null)
-			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), NotFound);
+			return new ProblemReferenceBinding(CharOperation.subarray(compoundName, 0, i), null, ProblemReasons.NotFound);
 	}
 	if (!type.canBeSeenBy(fPackage))
-		return new ProblemReferenceBinding(compoundName, type, NotVisible);
+		return new ProblemReferenceBinding(compoundName, type, ProblemReasons.NotVisible);
 	return type;
 }
 private Binding findSingleImport(char[][] compoundName, boolean findStaticImports) {
@@ -444,10 +479,10 @@ private Binding findSingleImport(char[][] compoundName, boolean findStaticImport
 		// findType records the reference
 		// the name cannot be a package
 		if (environment.defaultPackage == null || compilerOptions().complianceLevel >= ClassFileConstants.JDK1_4)
-			return new ProblemReferenceBinding(compoundName, NotFound);
+			return new ProblemReferenceBinding(compoundName, null, ProblemReasons.NotFound);
 		ReferenceBinding typeBinding = findType(compoundName[0], environment.defaultPackage, fPackage);
 		if (typeBinding == null)
-			return new ProblemReferenceBinding(compoundName, NotFound);
+			return new ProblemReferenceBinding(compoundName, null, ProblemReasons.NotFound);
 		return typeBinding;
 	}
 
@@ -463,14 +498,14 @@ private Binding findSingleStaticImport(char[][] compoundName) {
 	if (binding instanceof PackageBinding) {
 		Binding temp = ((PackageBinding) binding).getTypeOrPackage(name);
 		if (temp != null && temp instanceof ReferenceBinding) // must resolve to a member type or field, not a top level type
-			return new ProblemReferenceBinding(compoundName, InvalidTypeForStaticImport);
+			return new ProblemReferenceBinding(compoundName, (ReferenceBinding) temp, ProblemReasons.InvalidTypeForStaticImport);
 		return binding; // cannot be a package, error is caught in sender
 	}
 
 	// look to see if its a static field first
 	ReferenceBinding type = (ReferenceBinding) binding;
 	FieldBinding field = findField(type, name, null, true);
-	if (field != null && field.isValidBinding() && field.isStatic() && field.canBeSeenBy(fPackage))
+	if (field != null && field.isValidBinding() && field.isStatic() && field.canBeSeenBy(type, null, this))
 		return field;
 
 	// look to see if there is a static method with the same selector
@@ -478,10 +513,13 @@ private Binding findSingleStaticImport(char[][] compoundName) {
 	if (method != null) return method;
 
 	type = findMemberType(name, type);
-	if (type == null || !type.isStatic())
-		return new ProblemReferenceBinding(compoundName, type, NotFound);
+	if (type == null || !type.isStatic()) {
+		if (field != null && !field.isValidBinding() && field.problemId() != ProblemReasons.NotFound)
+			return field;
+		return new ProblemReferenceBinding(compoundName, type, ProblemReasons.NotFound);
+	}
 	if (!type.canBeSeenBy(fPackage))
-		return new ProblemReferenceBinding(compoundName, type, NotVisible);
+		return new ProblemReferenceBinding(compoundName, type, ProblemReasons.NotVisible);
 	return type;
 }
 MethodBinding findStaticMethod(ReferenceBinding currentType, char[] selector) {
@@ -490,7 +528,7 @@ MethodBinding findStaticMethod(ReferenceBinding currentType, char[] selector) {
 
 	do {
 		MethodBinding[] methods = currentType.getMethods(selector);
-		if (methods != NoMethods) {
+		if (methods != Binding.NO_METHODS) {
 			for (int i = methods.length; --i >= 0;) {
 				MethodBinding method = methods[i];
 				if (method.isStatic() && method.canBeSeenBy(fPackage))
