@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2005 IBM Corporation and others.
+ * Copyright (c) 2003, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -32,24 +32,24 @@ int AddRef() {
 void createCOMInterfaces() {
 	/* Create each of the interfaces that this object implements */
 	supports = new XPCOMObject(new int[]{2, 0, 0}){
-		public int /*long*/ method0(int /*long*/[] args) {return queryInterface(args[0], args[1]);}
-		public int /*long*/ method1(int /*long*/[] args) {return AddRef();}
-		public int /*long*/ method2(int /*long*/[] args) {return Release();}
+		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long /*int*/ method2(long /*int*/[] args) {return Release();}
 	};
 	
 	promptService = new XPCOMObject(new int[]{2, 0, 0, 3, 5, 4, 6, 10, 7, 8, 7, 7}){
-		public int /*long*/ method0(int /*long*/[] args) {return queryInterface(args[0], args[1]);}
-		public int /*long*/ method1(int /*long*/[] args) {return AddRef();}
-		public int /*long*/ method2(int /*long*/[] args) {return Release();}
-		public int /*long*/ method3(int /*long*/[] args) {return Alert(args[0], args[1], args[2]);}
-		public int /*long*/ method4(int /*long*/[] args) {return AlertCheck(args[0], args[1], args[2], args[3], args[4]);}
-		public int /*long*/ method5(int /*long*/[] args) {return Confirm(args[0], args[1], args[2], args[3]);}
-		public int /*long*/ method6(int /*long*/[] args) {return ConfirmCheck(args[0], args[1], args[2], args[3], args[4], args[5]);}
-		public int /*long*/ method7(int /*long*/[] args) {return ConfirmEx(args[0], args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8], args[9]);}
-		public int /*long*/ method8(int /*long*/[] args) {return Prompt(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
-		public int /*long*/ method9(int /*long*/[] args) {return PromptUsernameAndPassword(args[0], args[1], args[2], args[3], args[4], args[5], args[6], args[7]);}
-		public int /*long*/ method10(int /*long*/[] args) {return PromptPassword(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
-		public int /*long*/ method11(int /*long*/[] args) {return Select(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
+		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long /*int*/ method3(long /*int*/[] args) {return Alert(args[0], args[1], args[2]);}
+		public long /*int*/ method4(long /*int*/[] args) {return AlertCheck(args[0], args[1], args[2], args[3], args[4]);}
+		public long /*int*/ method5(long /*int*/[] args) {return Confirm(args[0], args[1], args[2], args[3]);}
+		public long /*int*/ method6(long /*int*/[] args) {return ConfirmCheck(args[0], args[1], args[2], args[3], args[4], args[5]);}
+		public long /*int*/ method7(long /*int*/[] args) {return ConfirmEx(args[0], args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8], args[9]);}
+		public long /*int*/ method8(long /*int*/[] args) {return Prompt(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
+		public long /*int*/ method9(long /*int*/[] args) {return PromptUsernameAndPassword(args[0], args[1], args[2], args[3], args[4], args[5], args[6], args[7]);}
+		public long /*int*/ method10(long /*int*/[] args) {return PromptPassword(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
+		public long /*int*/ method11(long /*int*/[] args) {return Select(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);}
 	};		
 }
 
@@ -64,27 +64,27 @@ void disposeCOMInterfaces() {
 	}
 }
 
-int /*long*/ getAddress() {
+long /*int*/ getAddress() {
 	return promptService.getAddress();
 }
 
-int /*long*/ queryInterface(int /*long*/ riid, int /*long*/ ppvObject) {
+long /*int*/ QueryInterface(long /*int*/ riid, long /*int*/ ppvObject) {
 	if (riid == 0 || ppvObject == 0) return XPCOM.NS_ERROR_NO_INTERFACE;
 	nsID guid = new nsID();
 	XPCOM.memmove(guid, riid, nsID.sizeof);
 	
 	if (guid.Equals(nsISupports.NS_ISUPPORTS_IID)) {
-		XPCOM.memmove(ppvObject, new int /*long*/[] {supports.getAddress()}, OS.PTR_SIZEOF);
+		XPCOM.memmove(ppvObject, new long /*int*/[] {supports.getAddress()}, OS.PTR_SIZEOF);
 		AddRef();
 		return XPCOM.NS_OK;
 	}
 	if (guid.Equals(nsIPromptService.NS_IPROMPTSERVICE_IID)) {
-		XPCOM.memmove(ppvObject, new int /*long*/[] {promptService.getAddress()}, OS.PTR_SIZEOF);
+		XPCOM.memmove(ppvObject, new long /*int*/[] {promptService.getAddress()}, OS.PTR_SIZEOF);
 		AddRef();
 		return XPCOM.NS_OK;
 	}
 	
-	XPCOM.memmove(ppvObject, new int /*long*/[] {0}, OS.PTR_SIZEOF);
+	XPCOM.memmove(ppvObject, new long /*int*/[] {0}, OS.PTR_SIZEOF);
 	return XPCOM.NS_ERROR_NO_INTERFACE;
 }
         	
@@ -94,8 +94,8 @@ int Release() {
 	return refCount;
 }
 
-Browser getBrowser(int /*long*/ aDOMWindow) {
-	int /*long*/[] result = new int /*long*/[1];
+Browser getBrowser(long /*int*/ aDOMWindow) {
+	long /*int*/[] result = new long /*int*/[1];
 	int rc = XPCOM.NS_GetServiceManager(result);
 	if (rc != XPCOM.NS_OK) Browser.error(rc);
 	if (result[0] == 0) Browser.error(XPCOM.NS_NOINTERFACE);
@@ -134,7 +134,7 @@ Browser getBrowser(int /*long*/ aDOMWindow) {
 	return Browser.findBrowser(result[0]); 
 }
 
-String getLabel(int buttonFlag, int index, int /*long*/ buttonTitle) {
+String getLabel(int buttonFlag, int index, long /*int*/ buttonTitle) {
 	String label = null;
 	int flag = (buttonFlag & (0xff * index)) / index;
 	switch (flag) {
@@ -155,7 +155,7 @@ String getLabel(int buttonFlag, int index, int /*long*/ buttonTitle) {
 
 /* nsIPromptService */
 
-public int /*long*/ Alert(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text) {
+public long /*int*/ Alert(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text) {
 	Browser browser = getBrowser(parent);
 	
 	int length = XPCOM.strlen_PRUnichar(dialogTitle);
@@ -168,18 +168,18 @@ public int /*long*/ Alert(int /*long*/ parent, int /*long*/ dialogTitle, int /*l
 	XPCOM.memmove(dest, text, length * 2);
 	String textLabel = new String(dest);
 
-	MessageBox messageBox = new MessageBox(browser.getShell(), SWT.OK);
+	MessageBox messageBox = new MessageBox(browser.getShell(), SWT.OK | SWT.ICON_WARNING);
 	messageBox.setText(titleLabel);
 	messageBox.setMessage(textLabel);
 	messageBox.open();
 	return XPCOM.NS_OK;
 }
 
-public int /*long*/ AlertCheck(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ checkMsg, int /*long*/ checkValue) {
+public long /*int*/ AlertCheck(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ checkMsg, long /*int*/ checkValue) {
 	return XPCOM.NS_ERROR_NOT_IMPLEMENTED;
 }
 
-public int /*long*/ Confirm(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ _retval) {
+public long /*int*/ Confirm(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ _retval) {
 	Browser browser = getBrowser(parent);
 	
 	int length = XPCOM.strlen_PRUnichar(dialogTitle);
@@ -192,7 +192,7 @@ public int /*long*/ Confirm(int /*long*/ parent, int /*long*/ dialogTitle, int /
 	XPCOM.memmove(dest, text, length * 2);
 	String textLabel = new String(dest);
 
-	MessageBox messageBox = new MessageBox(browser.getShell(), SWT.OK | SWT.CANCEL);
+	MessageBox messageBox = new MessageBox(browser.getShell(), SWT.OK | SWT.CANCEL | SWT.ICON_QUESTION);
 	messageBox.setText(titleLabel);
 	messageBox.setMessage(textLabel);
 	int id = messageBox.open();
@@ -201,11 +201,11 @@ public int /*long*/ Confirm(int /*long*/ parent, int /*long*/ dialogTitle, int /
 	return XPCOM.NS_OK;
 }
 
-public int /*long*/ ConfirmCheck(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ checkMsg, int /*long*/ checkValue, int /*long*/ _retval) {
+public long /*int*/ ConfirmCheck(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ checkMsg, long /*int*/ checkValue, long /*int*/ _retval) {
 	return XPCOM.NS_ERROR_NOT_IMPLEMENTED;
 }
 
-public int /*long*/ ConfirmEx(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ buttonFlags, int /*long*/ button0Title, int /*long*/ button1Title, int /*long*/ button2Title, int /*long*/ checkMsg, int /*long*/ checkValue, int /*long*/ _retval) {
+public long /*int*/ ConfirmEx(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ buttonFlags, long /*int*/ button0Title, long /*int*/ button1Title, long /*int*/ button2Title, long /*int*/ checkMsg, long /*int*/ checkValue, long /*int*/ _retval) {
 	Browser browser = getBrowser(parent);
 	
 	int length = XPCOM.strlen_PRUnichar(dialogTitle);
@@ -232,14 +232,14 @@ public int /*long*/ ConfirmEx(int /*long*/ parent, int /*long*/ dialogTitle, int
 	
 	PromptDialog dialog = new PromptDialog(browser.getShell());
 	int[] check = new int[1], result = new int[1];
-	if (checkValue != 0) XPCOM.memmove(check, (int)/*64*/checkValue, 4);
+	if (checkValue != 0) XPCOM.memmove(check, checkValue, 4);
 	dialog.confirmEx(titleLabel, textLabel, checkLabel, button1Label, button2Label, button3Label, check, result);
 	if (checkValue != 0) XPCOM.memmove(checkValue, check, 4);
 	XPCOM.memmove(_retval, result, 4);
 	return XPCOM.NS_OK;
 }
 
-public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ value, int /*long*/ checkMsg, int /*long*/ checkValue, int /*long*/ _retval) {
+public long /*int*/ Prompt(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ value, long /*int*/ checkMsg, long /*int*/ checkValue, long /*int*/ _retval) {
 	Browser browser = getBrowser(parent);
 	String titleLabel = null, textLabel, checkLabel = null;
 	String[] valueLabel = new String[1];
@@ -257,7 +257,7 @@ public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*
 	XPCOM.memmove(dest, text, length * 2);
 	textLabel = new String(dest);
 	
-	int /*long*/[] valueAddr = new int /*long*/[1];
+	long /*int*/[] valueAddr = new long /*int*/[1];
 	XPCOM.memmove(valueAddr, value, OS.PTR_SIZEOF);
 	if (valueAddr[0] != 0) {
 		length = XPCOM.strlen_PRUnichar(valueAddr[0]);
@@ -275,7 +275,7 @@ public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*
 	
 	PromptDialog dialog = new PromptDialog(browser.getShell());
 	int[] check = new int[1], result = new int[1];
-	if (checkValue != 0) XPCOM.memmove(check, (int)/*64*/checkValue, 4);
+	if (checkValue != 0) XPCOM.memmove(check, checkValue, 4);
 	dialog.prompt(titleLabel, textLabel, checkLabel, valueLabel, check, result);
 
 	XPCOM.memmove(_retval, result, 4);
@@ -285,9 +285,9 @@ public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*
 		* value that we override must be freed using the nsIMemory service.
 		*/
 		int cnt, size;
-		int /*long*/ ptr;
+		long /*int*/ ptr;
 		char[] buffer;
-		int /*long*/[] result2 = new int /*long*/[1];
+		long /*int*/[] result2 = new long /*int*/[1];
 		if (valueLabel[0] != null) {
 			cnt = valueLabel[0].length();
 			buffer = new char[cnt + 1];
@@ -295,7 +295,7 @@ public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*
 			size = buffer.length * 2;
 			ptr = XPCOM.PR_Malloc(size);
 			XPCOM.memmove(ptr, buffer, size);
-			XPCOM.memmove(value, new int /*long*/[] {ptr}, OS.PTR_SIZEOF);
+			XPCOM.memmove(value, new long /*int*/[] {ptr}, OS.PTR_SIZEOF);
 
 			if (valueAddr[0] != 0) {
 				int rc = XPCOM.NS_GetServiceManager(result2);
@@ -323,9 +323,9 @@ public int /*long*/ Prompt(int /*long*/ parent, int /*long*/ dialogTitle, int /*
 	return XPCOM.NS_OK;
 }
 
-public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ username, int /*long*/ password, int /*long*/ checkMsg, int /*long*/ checkValue, int /*long*/ _retval) {
+public long /*int*/ PromptUsernameAndPassword(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ username, long /*int*/ password, long /*int*/ checkMsg, long /*int*/ checkValue, long /*int*/ _retval) {
 	Browser browser = getBrowser(parent);
-	String titleLabel = null, textLabel, checkLabel = null;
+	String titleLabel, textLabel, checkLabel = null;
 	String[] userLabel = new String[1], passLabel = new String[1];
 	char[] dest;
 	int length;
@@ -334,6 +334,8 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 		dest = new char[length];
 		XPCOM.memmove(dest, dialogTitle, length * 2);
 		titleLabel = new String(dest);
+	} else {
+		titleLabel = "";	//$NON-NLS-1$
 	}
 	
 	length = XPCOM.strlen_PRUnichar(text);
@@ -341,7 +343,7 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 	XPCOM.memmove(dest, text, length * 2);
 	textLabel = new String(dest);
 	
-	int /*long*/[] userAddr = new int /*long*/[1];
+	long /*int*/[] userAddr = new long /*int*/[1];
 	XPCOM.memmove(userAddr, username, OS.PTR_SIZEOF);
 	if (userAddr[0] != 0) {
 		length = XPCOM.strlen_PRUnichar(userAddr[0]);
@@ -350,7 +352,7 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 		userLabel[0] = new String(dest);		
 	}
 	
-	int /*long*/[] passAddr = new int /*long*/[1];
+	long /*int*/[] passAddr = new long /*int*/[1];
 	XPCOM.memmove(passAddr, password, OS.PTR_SIZEOF);
 	if (passAddr[0] != 0) {
 		length = XPCOM.strlen_PRUnichar(passAddr[0]);
@@ -368,7 +370,7 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 	
 	PromptDialog dialog = new PromptDialog(browser.getShell());
 	int[] check = new int[1], result = new int[1];
-	if (checkValue != 0) XPCOM.memmove(check, (int)/*64*/checkValue, 4);
+	if (checkValue != 0) XPCOM.memmove(check, checkValue, 4);
 	dialog.promptUsernameAndPassword(titleLabel, textLabel, checkLabel, userLabel, passLabel, check, result);
 
 	XPCOM.memmove(_retval, result, 4);
@@ -378,9 +380,9 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 		* value that we override must be freed using the nsIMemory service.
 		*/
 		int cnt, size;
-		int /*long*/ ptr;
+		long /*int*/ ptr;
 		char[] buffer;
-		int /*long*/[] result2 = new int /*long*/[1];
+		long /*int*/[] result2 = new long /*int*/[1];
 		if (userLabel[0] != null) {
 			cnt = userLabel[0].length();
 			buffer = new char[cnt + 1];
@@ -388,7 +390,7 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 			size = buffer.length * 2;
 			ptr = XPCOM.PR_Malloc(size);
 			XPCOM.memmove(ptr, buffer, size);
-			XPCOM.memmove(username, new int /*long*/[] {ptr}, OS.PTR_SIZEOF);
+			XPCOM.memmove(username, new long /*int*/[] {ptr}, OS.PTR_SIZEOF);
 
 			if (userAddr[0] != 0) {
 				int rc = XPCOM.NS_GetServiceManager(result2);
@@ -418,7 +420,7 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 			size = buffer.length * 2;
 			ptr = XPCOM.PR_Malloc(size);
 			XPCOM.memmove(ptr, buffer, size);
-			XPCOM.memmove(password, new int /*long*/[] {ptr}, OS.PTR_SIZEOF);
+			XPCOM.memmove(password, new long /*int*/[] {ptr}, OS.PTR_SIZEOF);
 			
 			if (passAddr[0] != 0) {
 				int rc = XPCOM.NS_GetServiceManager(result2);
@@ -446,11 +448,11 @@ public int /*long*/ PromptUsernameAndPassword(int /*long*/ parent, int /*long*/
 	return XPCOM.NS_OK;
 }
 
-public int /*long*/ PromptPassword(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ password, int /*long*/ checkMsg, int /*long*/ checkValue, int /*long*/ _retval) {
+public long /*int*/ PromptPassword(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ password, long /*int*/ checkMsg, long /*int*/ checkValue, long /*int*/ _retval) {
 	return XPCOM.NS_ERROR_NOT_IMPLEMENTED;
 }
 
-public int /*long*/ Select(int /*long*/ parent, int /*long*/ dialogTitle, int /*long*/ text, int /*long*/ count, int /*long*/ selectList, int /*long*/ outSelection, int /*long*/ _retval) {
+public long /*int*/ Select(long /*int*/ parent, long /*int*/ dialogTitle, long /*int*/ text, long /*int*/ count, long /*int*/ selectList, long /*int*/ outSelection, long /*int*/ _retval) {
 	return XPCOM.NS_ERROR_NOT_IMPLEMENTED;
 }
 }
