@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2005 IBM Corporation and others.
+ * Copyright (c) 2000, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -81,7 +81,8 @@ import org.eclipse.swt.events.*;
  */
 public class ScrollBar extends Widget {
 	Scrollable parent;
-	int /*long*/ adjustmentHandle;
+	long /*int*/ adjustmentHandle;
+	int detail;
 	
 ScrollBar () {
 }
@@ -130,7 +131,7 @@ ScrollBar (Scrollable parent, int style) {
 public void addSelectionListener (SelectionListener listener) {
 	checkWidget ();
 	if (listener == null) error (SWT.ERROR_NULL_ARGUMENT);
-	TypedListener typedListener = new TypedListener(listener);
+	TypedListener typedListener = new TypedListener (listener);
 	addListener (SWT.Selection,typedListener);
 	addListener (SWT.DefaultSelection,typedListener);
 }
@@ -285,14 +286,13 @@ public int getSelection () {
 public Point getSize () {
 	checkWidget ();
 	if (handle == 0) return new Point (0,0);
-	int /*long*/ scrolledHandle = parent.scrolledHandle;
 	GtkRequisition requisition = new GtkRequisition ();
 	OS.gtk_widget_size_request (handle, requisition);
 	return new Point (requisition.width, requisition.height);
 }
 
 /**
- * Answers the size of the receiver's thumb relative to the
+ * Returns the size of the receiver's thumb relative to the
  * difference between its maximum and minimum values.
  *
  * @return the thumb value
@@ -330,7 +330,7 @@ public int getThumb () {
  */
 public boolean getVisible () {
 	checkWidget ();
-	int /*long*/ scrolledHandle = parent.scrolledHandle;
+	long /*int*/ scrolledHandle = parent.scrolledHandle;
 	int [] hsp = new int [1], vsp = new int [1];
 	OS.gtk_scrolled_window_get_policy (scrolledHandle, hsp, vsp);
 	if ((style & SWT.HORIZONTAL) != 0) {
@@ -340,14 +340,43 @@ public boolean getVisible () {
 	}
 }
 
-int /*long*/ gtk_value_changed (int /*long*/ adjustment) {
-	postEvent (SWT.Selection);
+long /*int*/ gtk_change_value (long /*int*/ widget, long /*int*/ scroll, long /*int*/ value1, long /*int*/ value2) {
+	detail = (int)/*64*/scroll;
+	return 0;
+}
+
+long /*int*/ gtk_value_changed (long /*int*/ adjustment) {
+	Event event = new Event ();
+	switch (detail) {
+		case OS.GTK_SCROLL_NONE:			event.detail = SWT.NONE; break;
+		case OS.GTK_SCROLL_JUMP:			event.detail = SWT.DRAG; break;
+		case OS.GTK_SCROLL_START:			event.detail = SWT.HOME; break;
+		case OS.GTK_SCROLL_END:				event.detail = SWT.END; break;
+		case OS.GTK_SCROLL_PAGE_DOWN:
+		case OS.GTK_SCROLL_PAGE_RIGHT:
+		case OS.GTK_SCROLL_PAGE_FORWARD:	event.detail = SWT.PAGE_DOWN; break;
+		case OS.GTK_SCROLL_PAGE_UP:
+		case OS.GTK_SCROLL_PAGE_LEFT:
+		case OS.GTK_SCROLL_PAGE_BACKWARD:	event.detail = SWT.PAGE_UP; break;
+		case OS.GTK_SCROLL_STEP_DOWN:
+		case OS.GTK_SCROLL_STEP_RIGHT:
+		case OS.GTK_SCROLL_STEP_FORWARD:	event.detail = SWT.ARROW_DOWN; break;
+		case OS.GTK_SCROLL_STEP_UP:
+		case OS.GTK_SCROLL_STEP_LEFT:
+		case OS.GTK_SCROLL_STEP_BACKWARD:	event.detail = SWT.ARROW_UP; break;
+	}
+	detail = OS.GTK_SCROLL_NONE;
+	postEvent (SWT.Selection, event);
+	parent.updateScrollBarValue (this);
 	return 0;
 }
 
 void hookEvents () {
 	super.hookEvents ();
-	OS.g_signal_connect (adjustmentHandle, OS.value_changed, display.windowProc2, VALUE_CHANGED);
+	if (OS.GTK_VERSION >= OS.VERSION (2, 6, 0)) {
+		OS.g_signal_connect_closure (handle, OS.change_value, display.closures [CHANGE_VALUE], false);
+	}
+	OS.g_signal_connect_closure (adjustmentHandle, OS.value_changed, display.closures [VALUE_CHANGED], false);
 }
 
 /**
@@ -394,8 +423,8 @@ void register () {
 	if (adjustmentHandle != 0) display.addWidget (adjustmentHandle, this);
 }
 
-void releaseChild () {
-	super.releaseChild ();
+void releaseParent () {
+	super.releaseParent ();
 	if (parent.horizontalBar == this) parent.horizontalBar = null;
 	if (parent.verticalBar == this) parent.verticalBar = null;
 }
@@ -607,7 +636,7 @@ public void setThumb (int value) {
  * Sets the receiver's selection, minimum value, maximum
  * value, thumb, increment and page increment all at once.
  * <p>
- * Note: This is equivalent to setting the values individually
+ * Note: This is similar to setting the values individually
  * using the appropriate methods, but may be implemented in a 
  * more efficient fashion on some platforms.
  * </p>
